@@ -303,13 +303,15 @@ This package only works for Win32, since it use AtiveX.
 
 =head1 SEE ALSO
 
-L<Wx:ActiveX> L<Wx>
+L<Wx::ActiveX> L<Wx>
 
 =head1 AUTHOR
 
 Graciliano M. P. <gm@virtuasites.com.br>
+
 Thanks to wxWindows peoples and Mattia Barbon for wxPerl! :P
-Thanks to Justin Bradford <justin@maxwell.ucsf.edu> and Lindsay Mathieson <lmathieson@optusnet.com.au>, that wrote the C classes for wxActiveX and wxIEHtmlWin.
+
+Thanks to Justin Bradford <justin@maxwell.ucsf.edu> and Lindsay Mathieson <lmathieson@optusnet.com.au>, that wrote the original C++ classes for wxActiveX and wxIEHtmlWin.
 
 =head1 COPYRIGHT
 
